@@ -227,7 +227,7 @@ class Member(TimeStampedModel):
     )
     first_name = models.CharField(max_length=30, blank=False)
     last_name = models.CharField(max_length=30, blank=False, null=True)
-    office_email = models.EmailField(max_length=250)
+    office_email = models.EmailField(null=True, blank=True, max_length=250)
     inactive = models.BooleanField(default=False)
     avatar = models.CharField(
         null=True, blank=True, max_length=250,
@@ -1012,6 +1012,14 @@ class Project(TimeStampedModel):
     def __str__(self):
         return self.name or ''
 
+    def update_cw(self):
+        """
+        Send project status updates to ConnectWise.
+        """
+        api_client = api.ProjectAPIClient()
+
+        return api_client.update_project(self.id, self.status)
+
 
 class OpportunityStage(TimeStampedModel):
     name = models.CharField(max_length=50)
